@@ -11,24 +11,42 @@ import pytest
 
 
 @pytest.mark.parametrize(
-    "country_code_column, country_code, holiday_step, error",
+    "country_code_column, country_code, days_before, days_after, bridge_days, holiday_step, error",
     [
-        (None, None, str, None),
-        ("region", None, Pipeline, None),
-        (["region_a", "region_b"], None, Pipeline, None),
-        (None, "DE", Pipeline, None),
-        (None, ["DE", "BE"], Pipeline, None),
-        ("region", "DE", None, ValueError),
+        (None, None, 0, 1, True, str, None),
+        ("region", None, 2, 1, True, Pipeline, None),
+        (["region_a", "region_b"], None, 0, 0, False, Pipeline, None),
+        (None, "DE", 5, 5, False, Pipeline, None),
+        (None, ["DE", "BE"], 3, 3, True, Pipeline, None),
+        ("region", "DE", 0, 0, True, None, ValueError),
     ],
 )
-def test_model_selector_holidays(country_code_column, country_code, holiday_step, error):
+def test_model_selector_holidays(
+    country_code_column,
+    country_code,
+    days_before,
+    days_after,
+    bridge_days,
+    holiday_step,
+    error,
+):
     ms = ModelSelector(frequency="D", horizon=1, country_code_column=country_code_column)
 
     if error is not None:
         with pytest.raises(error):
-            ms.create_gridsearch(country_code=country_code)
+            ms.create_gridsearch(
+                country_code=country_code,
+                holidays_days_before=days_before,
+                holidays_days_after=days_after,
+                holidays_bridge_days=bridge_days,
+            )
     else:
-        ms.create_gridsearch(country_code=country_code)
+        ms.create_gridsearch(
+            country_code=country_code,
+            holidays_days_before=days_before,
+            holidays_days_after=days_after,
+            holidays_bridge_days=bridge_days,
+        )
         assert isinstance(ms.grid_search.estimator.named_steps["holiday"], holiday_step)
 
         if holiday_step is not str:
@@ -59,6 +77,24 @@ def test_model_selector_holidays(country_code_column, country_code, holiday_step
                     )
                 ]
             )
+            assert all(
+                [
+                    step[1].days_before == days_before
+                    for step in ms.grid_search.estimator.named_steps["holiday"].steps
+                ]
+            )
+            assert all(
+                [
+                    step[1].days_after == days_after
+                    for step in ms.grid_search.estimator.named_steps["holiday"].steps
+                ]
+            )
+            assert all(
+                [
+                    step[1].bridge_days == bridge_days
+                    for step in ms.grid_search.estimator.named_steps["holiday"].steps
+                ]
+            )
 
 
 def test_model_selector(tmp_path):
@@ -100,7 +136,9 @@ def test_model_selector(tmp_path):
 
     ms.add_model_to_gridsearch(get_sklearn_wrapper(LinearRegression))
     ms.select_model(
-        df=df, target_col_name=target_col_name, partition_columns=["Region", "Plant", "Product"],
+        df=df,
+        target_col_name=target_col_name,
+        partition_columns=["Region", "Plant", "Product"],
     )
 
     assert len(ms.results) == n_regions * n_plants * n_products
